@@ -561,13 +561,13 @@ if(!censor)fcn <- switch(distribution,
 		u <- s*(1-m)
 		lbeta(y[,1]+t,y[,2]+u)-lbeta(t,u)+lchoose(nn,y[,1])},
 	"double binomial"=function(m,p)
-		.C("ddb",as.integer(y[,1]),as.integer(nn),
+		.C("ddb_c",as.integer(y[,1]),as.integer(nn),
 			as.double(m),as.double(exp(sh1(p))),
 			as.integer(n),as.double(wt),res=double(n),
 			#DUP=FALSE,
 			PACKAGE="repeated")$res,
 	"mult binomial"=function(m,p)
-		.C("dmb",as.integer(y[,1]),as.integer(nn),
+		.C("dmb_c",as.integer(y[,1]),as.integer(nn),
 			as.double(m),as.double(exp(sh1(p))),
 			as.integer(n),as.double(wt),res=double(n),
 			#DUP=FALSE,
@@ -575,13 +575,13 @@ if(!censor)fcn <- switch(distribution,
 	Poisson=function(m,p)dpois(y,m,TRUE),
 	"negative binomial"=function(m,p)dnbinom(y,exp(sh1(p)),mu=m,log=TRUE),
 	"double Poisson"=function(m,p)
-		.C("ddp",as.integer(y),as.integer(my),as.double(m),
+		.C("ddp_c",as.integer(y),as.integer(my),as.double(m),
 			as.double(exp(sh1(p))),as.integer(n),as.double(wt),
 			res=double(n),
 			#DUP=FALSE,
 			PACKAGE="repeated")$res,
 	"mult Poisson"=function(m,p)
-		.C("dmp",as.integer(y),as.integer(my),
+		.C("dmp_c",as.integer(y),as.integer(my),
 			as.double(m),as.double(exp(sh1(p))),
 			as.integer(n),as.double(wt),res=double(n),
 			#DUP=FALSE,
